# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from ....protocol.v30 import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nScom/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x91\x0c\n\x11SequencerSnapshot\x12)\n\x10latest_timestamp\x18\x01 \x01(\x03R\x0flatestTimestamp\x12*\n\x11last_block_height\x18\x02 \x01(\x04R\x0flastBlockHeight\x12~\n\x14head_member_counters\x18\x03 \x03(\x0b\x32L.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.MemberCounterR\x12headMemberCounters\x12[\n\x06status\x18\x04 \x01(\x0b\x32\x43.com.digitalasset.canton.sequencer.admin.v30.SequencerPruningStatusR\x06status\x12g\n\nadditional\x18\x05 \x01(\x0b\x32G.com.digitalasset.canton.sequencer.admin.v30.ImplementationSpecificInfoR\nadditional\x12\x8e\x01\n\x16in_flight_aggregations\x18\x06 \x03(\x0b\x32X.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.InFlightAggregationWithIdR\x14inFlightAggregations\x12\x63\n\x11traffic_purchased\x18\x07 \x03(\x0b\x32\x36.com.digitalasset.canton.protocol.v30.TrafficPurchasedR\x10trafficPurchased\x12`\n\x10traffic_consumed\x18\x08 \x03(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TrafficConsumedR\x0ftrafficConsumed\x1aT\n\rMemberCounter\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12+\n\x11sequencer_counter\x18\x02 \x01(\x03R\x10sequencerCounter\x1a\xd8\x02\n\x19InFlightAggregationWithId\x12%\n\x0e\x61ggregation_id\x18\x01 \x01(\x0cR\raggregationId\x12`\n\x10\x61ggregation_rule\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.AggregationRuleR\x0f\x61ggregationRule\x12.\n\x13max_sequencing_time\x18\x03 \x01(\x03R\x11maxSequencingTime\x12\x81\x01\n\x12\x61ggregated_senders\x18\x04 \x03(\x0b\x32R.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.AggregationBySenderR\x11\x61ggregatedSenders\x1a\xed\x01\n\x13\x41ggregationBySender\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x31\n\x14sequencing_timestamp\x18\x02 \x01(\x03R\x13sequencingTimestamp\x12\x8a\x01\n\x16signatures_by_envelope\x18\x03 \x03(\x0b\x32T.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshot.SignaturesForEnvelopeR\x14signaturesByEnvelope\x1a\x66\n\x15SignaturesForEnvelope\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"\xb8\x01\n\x15SequencerMemberStatus\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12#\n\rregistered_at\x18\x02 \x01(\x03R\x0cregisteredAt\x12H\n\x11last_acknowledged\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x10lastAcknowledged\x12\x18\n\x07\x65nabled\x18\x04 \x01(\x08R\x07\x65nabled\"\xc2\x01\n\x16SequencerPruningStatus\x12\x10\n\x03now\x18\x01 \x01(\x03R\x03now\x12\x38\n\x18\x65\x61rliest_event_timestamp\x18\x02 \x01(\x03R\x16\x65\x61rliestEventTimestamp\x12\\\n\x07members\x18\x03 \x03(\x0b\x32\x42.com.digitalasset.canton.sequencer.admin.v30.SequencerMemberStatusR\x07members\"a\n\x1aImplementationSpecificInfo\x12/\n\x13implementation_name\x18\x01 \x01(\tR\x12implementationName\x12\x12\n\x04info\x18\x02 \x01(\x0cR\x04infoB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_initialization_snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_SEQUENCERSNAPSHOT']._serialized_start=343
  _globals['_SEQUENCERSNAPSHOT']._serialized_end=1896
  _globals['_SEQUENCERSNAPSHOT_MEMBERCOUNTER']._serialized_start=1121
  _globals['_SEQUENCERSNAPSHOT_MEMBERCOUNTER']._serialized_end=1205
  _globals['_SEQUENCERSNAPSHOT_INFLIGHTAGGREGATIONWITHID']._serialized_start=1208
  _globals['_SEQUENCERSNAPSHOT_INFLIGHTAGGREGATIONWITHID']._serialized_end=1552
  _globals['_SEQUENCERSNAPSHOT_AGGREGATIONBYSENDER']._serialized_start=1555
  _globals['_SEQUENCERSNAPSHOT_AGGREGATIONBYSENDER']._serialized_end=1792
  _globals['_SEQUENCERSNAPSHOT_SIGNATURESFORENVELOPE']._serialized_start=1794
  _globals['_SEQUENCERSNAPSHOT_SIGNATURESFORENVELOPE']._serialized_end=1896
  _globals['_SEQUENCERMEMBERSTATUS']._serialized_start=1899
  _globals['_SEQUENCERMEMBERSTATUS']._serialized_end=2083
  _globals['_SEQUENCERPRUNINGSTATUS']._serialized_start=2086
  _globals['_SEQUENCERPRUNINGSTATUS']._serialized_end=2280
  _globals['_IMPLEMENTATIONSPECIFICINFO']._serialized_start=2282
  _globals['_IMPLEMENTATIONSPECIFICINFO']._serialized_end=2379
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/topology.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import domain_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_domain__parameters__pb2
from . import sequencing_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__parameters__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3com/digitalasset/canton/protocol/v30/topology.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a<com/digitalasset/canton/protocol/v30/domain_parameters.proto\x1a@com/digitalasset/canton/protocol/v30/sequencing_parameters.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xbc\x02\n\x05\x45nums\"y\n\x10TopologyChangeOp\x12\"\n\x1eTOPOLOGY_CHANGE_OP_UNSPECIFIED\x10\x00\x12\"\n\x1eTOPOLOGY_CHANGE_OP_ADD_REPLACE\x10\x01\x12\x1d\n\x19TOPOLOGY_CHANGE_OP_REMOVE\x10\x02\"\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\"\xb6\x01\n\x13NamespaceDelegation\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12S\n\ntarget_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\ttargetKey\x12,\n\x12is_root_delegation\x18\x03 \x01(\x08R\x10isRootDelegation\"\x91\x01\n DecentralizedNamespaceDefinition\x12\x37\n\x17\x64\x65\x63\x65ntralized_namespace\x18\x01 \x01(\tR\x16\x64\x65\x63\x65ntralizedNamespace\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold\x12\x16\n\x06owners\x18\x03 \x03(\tR\x06owners\"\x98\x01\n\x14IdentifierDelegation\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12S\n\ntarget_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\ttargetKey\"\x93\x01\n\x11OwnerToKeyMapping\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12N\n\x0bpublic_keys\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.PublicKeyR\npublicKeys\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\"\xb8\x01\n\x11PartyToKeyMapping\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12W\n\x0csigning_keys\x18\x04 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\x0bsigningKeys\"\xd1\x01\n\x16\x44omainTrustCertificate\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12O\n%transfer_only_to_given_target_domains\x18\x03 \x01(\x08R transferOnlyToGivenTargetDomains\x12%\n\x0etarget_domains\x18\x04 \x03(\tR\rtargetDomains\"\xd6\x02\n\x1bParticipantDomainPermission\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\'\n\x0fparticipant_uid\x18\x02 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12U\n\x06limits\x18\x04 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v30.ParticipantDomainLimitsR\x06limits\x12<\n\x0blogin_after\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nloginAfter\"X\n\x12PartyHostingLimits\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x14\n\x05party\x18\x02 \x01(\tR\x05party\x12\x14\n\x05quota\x18\x03 \x01(\rR\x05quota\"r\n\x0eVettedPackages\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x1f\n\x0bpackage_ids\x18\x02 \x03(\tR\npackageIds\x12\x16\n\x06\x64omain\x18\x03 \x01(\tR\x06\x64omain\"\x9f\x03\n\x12PartyToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12o\n\x0cparticipants\x18\x03 \x03(\x0b\x32K.com.digitalasset.canton.protocol.v30.PartyToParticipant.HostingParticipantR\x0cparticipants\x12)\n\x10group_addressing\x18\x04 \x01(\x08R\x0fgroupAddressing\x12\x16\n\x06\x64omain\x18\x05 \x01(\tR\x06\x64omain\x1a\xa0\x01\n\x12HostingParticipant\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x02 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\"s\n\x0b\x41uthorityOf\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12\x18\n\x07parties\x18\x03 \x03(\tR\x07parties\x12\x16\n\x06\x64omain\x18\x04 \x01(\tR\x06\x64omain\"\x9b\x01\n\x15\x44omainParametersState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12j\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.protocol.v30.DynamicDomainParametersR\x10\x64omainParameters\"\xb2\x01\n DynamicSequencingParametersState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12v\n\x15sequencing_parameters\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersR\x14sequencingParameters\"\x97\x01\n\x13MediatorDomainState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x14\n\x05group\x18\x02 \x01(\rR\x05group\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x04 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x05 \x03(\tR\tobservers\"\x82\x01\n\x14SequencerDomainState\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x03 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x04 \x03(\tR\tobservers\"\x85\x01\n\x18PurgeTopologyTransaction\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12Q\n\x08mappings\x18\x02 \x03(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x08mappings\"\xe1\x0e\n\x0fTopologyMapping\x12n\n\x14namespace_delegation\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationH\x00R\x13namespaceDelegation\x12q\n\x15identifier_delegation\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.IdentifierDelegationH\x00R\x14identifierDelegation\x12\x96\x01\n\"decentralized_namespace_definition\x18\x03 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionH\x00R decentralizedNamespaceDefinition\x12j\n\x14owner_to_key_mapping\x18\x04 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12x\n\x18\x64omain_trust_certificate\x18\x05 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.DomainTrustCertificateH\x00R\x16\x64omainTrustCertificate\x12z\n\x16participant_permission\x18\x06 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.ParticipantDomainPermissionH\x00R\x15participantPermission\x12l\n\x14party_hosting_limits\x18\x07 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsH\x00R\x12partyHostingLimits\x12_\n\x0fvetted_packages\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesH\x00R\x0evettedPackages\x12l\n\x14party_to_participant\x18\t \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantH\x00R\x12partyToParticipant\x12V\n\x0c\x61uthority_of\x18\n \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v30.AuthorityOfH\x00R\x0b\x61uthorityOf\x12u\n\x17\x64omain_parameters_state\x18\x0b \x01(\x0b\x32;.com.digitalasset.canton.protocol.v30.DomainParametersStateH\x00R\x15\x64omainParametersState\x12o\n\x15mediator_domain_state\x18\x0c \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.MediatorDomainStateH\x00R\x13mediatorDomainState\x12r\n\x16sequencer_domain_state\x18\r \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.SequencerDomainStateH\x00R\x14sequencerDomainState\x12n\n\x12purge_topology_txs\x18\x0e \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.PurgeTopologyTransactionH\x00R\x10purgeTopologyTxs\x12\x97\x01\n#sequencing_dynamic_parameters_state\x18\x0f \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersStateH\x00R sequencingDynamicParametersState\x12j\n\x14party_to_key_mapping\x18\x10 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingH\x00R\x11partyToKeyMappingB\t\n\x07mapping\"\xda\x01\n\x13TopologyTransaction\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\"\xa8\x01\n\x19SignedTopologyTransaction\x12 \n\x0btransaction\x18\x01 \x01(\x0cR\x0btransaction\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\x12\x1a\n\x08proposal\x18\x03 \x01(\x08R\x08proposal\"\xbc\x02\n\x1dTopologyTransactionsBroadcast\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12m\n\nbroadcasts\x18\x02 \x03(\x0b\x32M.com.digitalasset.canton.protocol.v30.TopologyTransactionsBroadcast.BroadcastR\nbroadcasts\x1a\x93\x01\n\tBroadcast\x12!\n\x0c\x62roadcast_id\x18\x01 \x01(\tR\x0b\x62roadcastId\x12\x63\n\x0ctransactions\x18\x02 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactionsBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_ENUMS']._serialized_start=303
  _globals['_ENUMS']._serialized_end=619
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_start=312
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_end=433
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_start=436
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_end=619
  _globals['_NAMESPACEDELEGATION']._serialized_start=622
  _globals['_NAMESPACEDELEGATION']._serialized_end=804
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_start=807
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_end=952
  _globals['_IDENTIFIERDELEGATION']._serialized_start=955
  _globals['_IDENTIFIERDELEGATION']._serialized_end=1107
  _globals['_OWNERTOKEYMAPPING']._serialized_start=1110
  _globals['_OWNERTOKEYMAPPING']._serialized_end=1257
  _globals['_PARTYTOKEYMAPPING']._serialized_start=1260
  _globals['_PARTYTOKEYMAPPING']._serialized_end=1444
  _globals['_DOMAINTRUSTCERTIFICATE']._serialized_start=1447
  _globals['_DOMAINTRUSTCERTIFICATE']._serialized_end=1656
  _globals['_PARTICIPANTDOMAINPERMISSION']._serialized_start=1659
  _globals['_PARTICIPANTDOMAINPERMISSION']._serialized_end=2001
  _globals['_PARTYHOSTINGLIMITS']._serialized_start=2003
  _globals['_PARTYHOSTINGLIMITS']._serialized_end=2091
  _globals['_VETTEDPACKAGES']._serialized_start=2093
  _globals['_VETTEDPACKAGES']._serialized_end=2207
  _globals['_PARTYTOPARTICIPANT']._serialized_start=2210
  _globals['_PARTYTOPARTICIPANT']._serialized_end=2625
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_start=2465
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_end=2625
  _globals['_AUTHORITYOF']._serialized_start=2627
  _globals['_AUTHORITYOF']._serialized_end=2742
  _globals['_DOMAINPARAMETERSSTATE']._serialized_start=2745
  _globals['_DOMAINPARAMETERSSTATE']._serialized_end=2900
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_start=2903
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_end=3081
  _globals['_MEDIATORDOMAINSTATE']._serialized_start=3084
  _globals['_MEDIATORDOMAINSTATE']._serialized_end=3235
  _globals['_SEQUENCERDOMAINSTATE']._serialized_start=3238
  _globals['_SEQUENCERDOMAINSTATE']._serialized_end=3368
  _globals['_PURGETOPOLOGYTRANSACTION']._serialized_start=3371
  _globals['_PURGETOPOLOGYTRANSACTION']._serialized_end=3504
  _globals['_TOPOLOGYMAPPING']._serialized_start=3507
  _globals['_TOPOLOGYMAPPING']._serialized_end=5396
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=5399
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=5617
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_start=5620
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_end=5788
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_start=5791
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_end=6107
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST_BROADCAST']._serialized_start=5960
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST_BROADCAST']._serialized_end=6107
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .domain_initialization_service_pb2 import DomainInitRequest, DomainNodeSequencerConfig
from .domain_initialization_service_pb2_grpc import DomainInitializationServiceStub
from .domain_service_pb2 import GetDomainParameters, ServiceAgreementAcceptance, ServiceAgreementAcceptances
from .domain_service_pb2_grpc import DomainServiceStub
from .enterprise_mediator_administration_service_pb2 import MediatorPruningRequest
from .enterprise_mediator_administration_service_pb2_grpc import EnterpriseMediatorAdministrationServiceStub
from .sequencer_administration_service_pb2 import SequencerMemberStatus, SequencerPruningStatus
from .sequencer_administration_service_pb2_grpc import SequencerAdministrationServiceStub
from .sequencer_initialization_snapshot_pb2 import ImplementationSpecificInfo, SequencerSnapshot
from .enterprise_sequencer_administration_service_pb2 import DisableMemberRequest, EthereumAccount, LedgerIdentity, Pruning, Snapshot
from .enterprise_sequencer_administration_service_pb2_grpc import EnterpriseSequencerAdministrationServiceStub
from .enterprise_sequencer_connection_service_pb2 import GetConnectionRequest, GetConnectionResponse, SetConnectionRequest
from .enterprise_sequencer_connection_service_pb2_grpc import EnterpriseSequencerConnectionServiceStub
from .mediator_initialization_service_pb2 import InitializeMediatorRequest, InitializeMediatorResponse
from .mediator_initialization_service_pb2_grpc import MediatorInitializationServiceStub
from .sequencer_initialization_service_pb2 import InitRequest, InitResponse, TopologyBootstrapRequest
from .sequencer_initialization_service_pb2_grpc import SequencerInitializationServiceStub, TopologyBootstrapServiceStub
from .sequencer_version_service_pb2_grpc import SequencerVersionServiceStub

__all__ = [
    "DisableMemberRequest",
    "DomainInitRequest",
    "DomainInitializationServiceStub",
    "DomainNodeSequencerConfig",
    "DomainServiceStub",
    "EnterpriseMediatorAdministrationServiceStub",
    "EnterpriseSequencerAdministrationServiceStub",
    "EnterpriseSequencerConnectionServiceStub",
    "EthereumAccount",
    "GetConnectionRequest",
    "GetConnectionResponse",
    "GetDomainParameters",
    "ImplementationSpecificInfo",
    "InitRequest",
    "InitResponse",
    "InitializeMediatorRequest",
    "InitializeMediatorResponse",
    "LedgerIdentity",
    "MediatorInitializationServiceStub",
    "MediatorPruningRequest",
    "Pruning",
    "SequencerAdministrationServiceStub",
    "SequencerInitializationServiceStub",
    "SequencerMemberStatus",
    "SequencerPruningStatus",
    "SequencerSnapshot",
    "SequencerVersionServiceStub",
    "ServiceAgreementAcceptance",
    "ServiceAgreementAcceptances",
    "SetConnectionRequest",
    "Snapshot",
    "TopologyBootstrapRequest",
    "TopologyBootstrapServiceStub",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...api.v0 import sequencer_connection_pb2 as _sequencer_connection_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DomainNodeSequencerConfig(_message.Message):
    __slots__ = ("sequencerConnection",)
    SEQUENCERCONNECTION_FIELD_NUMBER: _ClassVar[int]
    sequencerConnection: _sequencer_connection_pb2.SequencerConnection
    def __init__(self, sequencerConnection: _Optional[_Union[_sequencer_connection_pb2.SequencerConnection, _Mapping]] = ...) -> None: ...

class DomainInitRequest(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: DomainNodeSequencerConfig
    def __init__(self, config: _Optional[_Union[DomainNodeSequencerConfig, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import topology_pb2 as _topology_pb2
from . import sequencing_pb2 as _sequencing_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyStateUpdate(_message.Message):
    __slots__ = ("operation", "id", "namespace_delegation", "identifier_delegation", "owner_to_key_mapping", "party_to_participant", "signed_legal_identity_claim", "participant_state", "vetted_packages", "mediator_domain_state")
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    OWNER_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    SIGNED_LEGAL_IDENTITY_CLAIM_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_STATE_FIELD_NUMBER: _ClassVar[int]
    VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_DOMAIN_STATE_FIELD_NUMBER: _ClassVar[int]
    operation: _topology_pb2.TopologyChangeOp
    id: str
    namespace_delegation: _topology_pb2.NamespaceDelegation
    identifier_delegation: _topology_pb2.IdentifierDelegation
    owner_to_key_mapping: _topology_pb2.OwnerToKeyMapping
    party_to_participant: _topology_pb2.PartyToParticipant
    signed_legal_identity_claim: _topology_pb2.SignedLegalIdentityClaim
    participant_state: _topology_pb2.ParticipantState
    vetted_packages: _topology_pb2.VettedPackages
    mediator_domain_state: _topology_pb2.MediatorDomainState
    def __init__(self, operation: _Optional[_Union[_topology_pb2.TopologyChangeOp, str]] = ..., id: _Optional[str] = ..., namespace_delegation: _Optional[_Union[_topology_pb2.NamespaceDelegation, _Mapping]] = ..., identifier_delegation: _Optional[_Union[_topology_pb2.IdentifierDelegation, _Mapping]] = ..., owner_to_key_mapping: _Optional[_Union[_topology_pb2.OwnerToKeyMapping, _Mapping]] = ..., party_to_participant: _Optional[_Union[_topology_pb2.PartyToParticipant, _Mapping]] = ..., signed_legal_identity_claim: _Optional[_Union[_topology_pb2.SignedLegalIdentityClaim, _Mapping]] = ..., participant_state: _Optional[_Union[_topology_pb2.ParticipantState, _Mapping]] = ..., vetted_packages: _Optional[_Union[_topology_pb2.VettedPackages, _Mapping]] = ..., mediator_domain_state: _Optional[_Union[_topology_pb2.MediatorDomainState, _Mapping]] = ...) -> None: ...

class DomainParametersChange(_message.Message):
    __slots__ = ("domain", "domain_parameters")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    domain_parameters: _sequencing_pb2.DynamicDomainParameters
    def __init__(self, domain: _Optional[str] = ..., domain_parameters: _Optional[_Union[_sequencing_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...

class DomainGovernanceTransaction(_message.Message):
    __slots__ = ("domain_parameters_change",)
    DOMAIN_PARAMETERS_CHANGE_FIELD_NUMBER: _ClassVar[int]
    domain_parameters_change: DomainParametersChange
    def __init__(self, domain_parameters_change: _Optional[_Union[DomainParametersChange, _Mapping]] = ...) -> None: ...

class TopologyTransaction(_message.Message):
    __slots__ = ("state_update", "domain_governance")
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    state_update: TopologyStateUpdate
    domain_governance: DomainGovernanceTransaction
    def __init__(self, state_update: _Optional[_Union[TopologyStateUpdate, _Mapping]] = ..., domain_governance: _Optional[_Union[DomainGovernanceTransaction, _Mapping]] = ...) -> None: ...

class RegisterTopologyTransactionResponse(_message.Message):
    __slots__ = ("requested_by", "participant", "request_id", "results", "domain_id")
    class Result(_message.Message):
        __slots__ = ("state", "error_message")
        class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            MISSING_STATE: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            FAILED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            REJECTED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            ACCEPTED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            DUPLICATE: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            OBSOLETE: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
        MISSING_STATE: RegisterTopologyTransactionResponse.Result.State
        FAILED: RegisterTopologyTransactionResponse.Result.State
        REJECTED: RegisterTopologyTransactionResponse.Result.State
        ACCEPTED: RegisterTopologyTransactionResponse.Result.State
        DUPLICATE: RegisterTopologyTransactionResponse.Result.State
        OBSOLETE: RegisterTopologyTransactionResponse.Result.State
        STATE_FIELD_NUMBER: _ClassVar[int]
        ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        state: RegisterTopologyTransactionResponse.Result.State
        error_message: str
        def __init__(self, state: _Optional[_Union[RegisterTopologyTransactionResponse.Result.State, str]] = ..., error_message: _Optional[str] = ...) -> None: ...
    REQUESTED_BY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    requested_by: str
    participant: str
    request_id: str
    results: _containers.RepeatedCompositeFieldContainer[RegisterTopologyTransactionResponse.Result]
    domain_id: str
    def __init__(self, requested_by: _Optional[str] = ..., participant: _Optional[str] = ..., request_id: _Optional[str] = ..., results: _Optional[_Iterable[_Union[RegisterTopologyTransactionResponse.Result, _Mapping]]] = ..., domain_id: _Optional[str] = ...) -> None: ...

class DomainTopologyTransactionMessage(_message.Message):
    __slots__ = ("signature", "domain_id", "not_sequenced_after", "transactions")
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    NOT_SEQUENCED_AFTER_FIELD_NUMBER: _ClassVar[int]
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    signature: _crypto_pb2.Signature
    domain_id: str
    not_sequenced_after: _timestamp_pb2.Timestamp
    transactions: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., domain_id: _Optional[str] = ..., not_sequenced_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., transactions: _Optional[_Iterable[bytes]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PingRequest(_message.Message):
    __slots__ = ("target_parties", "validators", "timeout", "levels", "domain_id", "workflow_id", "id")
    TARGET_PARTIES_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    LEVELS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    target_parties: _containers.RepeatedScalarFieldContainer[str]
    validators: _containers.RepeatedScalarFieldContainer[str]
    timeout: _duration_pb2.Duration
    levels: int
    domain_id: str
    workflow_id: str
    id: str
    def __init__(self, target_parties: _Optional[_Iterable[str]] = ..., validators: _Optional[_Iterable[str]] = ..., timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., levels: _Optional[int] = ..., domain_id: _Optional[str] = ..., workflow_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class PingSuccess(_message.Message):
    __slots__ = ("ping_time", "responder")
    PING_TIME_FIELD_NUMBER: _ClassVar[int]
    RESPONDER_FIELD_NUMBER: _ClassVar[int]
    ping_time: int
    responder: str
    def __init__(self, ping_time: _Optional[int] = ..., responder: _Optional[str] = ...) -> None: ...

class PingFailure(_message.Message):
    __slots__ = ("reason",)
    REASON_FIELD_NUMBER: _ClassVar[int]
    reason: str
    def __init__(self, reason: _Optional[str] = ...) -> None: ...

class PingResponse(_message.Message):
    __slots__ = ("success", "failure")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    success: PingSuccess
    failure: PingFailure
    def __init__(self, success: _Optional[_Union[PingSuccess, _Mapping]] = ..., failure: _Optional[_Union[PingFailure, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import experimental_features_pb2 as _experimental_features_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetLedgerApiVersionRequest(_message.Message):
    __slots__ = ("ledger_id",)
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    def __init__(self, ledger_id: _Optional[str] = ...) -> None: ...

class GetLedgerApiVersionResponse(_message.Message):
    __slots__ = ("version", "features")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    version: str
    features: FeaturesDescriptor
    def __init__(self, version: _Optional[str] = ..., features: _Optional[_Union[FeaturesDescriptor, _Mapping]] = ...) -> None: ...

class FeaturesDescriptor(_message.Message):
    __slots__ = ("user_management", "party_management", "experimental")
    USER_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    PARTY_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENTAL_FIELD_NUMBER: _ClassVar[int]
    user_management: UserManagementFeature
    party_management: PartyManagementFeature
    experimental: _experimental_features_pb2.ExperimentalFeatures
    def __init__(self, user_management: _Optional[_Union[UserManagementFeature, _Mapping]] = ..., party_management: _Optional[_Union[PartyManagementFeature, _Mapping]] = ..., experimental: _Optional[_Union[_experimental_features_pb2.ExperimentalFeatures, _Mapping]] = ...) -> None: ...

class UserManagementFeature(_message.Message):
    __slots__ = ("supported", "max_rights_per_user", "max_users_page_size")
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    MAX_RIGHTS_PER_USER_FIELD_NUMBER: _ClassVar[int]
    MAX_USERS_PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    max_rights_per_user: int
    max_users_page_size: int
    def __init__(self, supported: bool = ..., max_rights_per_user: _Optional[int] = ..., max_users_page_size: _Optional[int] = ...) -> None: ...

class PartyManagementFeature(_message.Message):
    __slots__ = ("max_parties_page_size",)
    MAX_PARTIES_PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    max_parties_page_size: int
    def __init__(self, max_parties_page_size: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from dataclasses import asdict
import logging
from pathlib import Path
from typing import Optional

from . import codegen, protopack
from .download import download_dependencies

repo_root = Path(__file__).parent.parent.parent

logger = logging.getLogger("_dazl")

__all__ = ["update"]


def update(
    *,
    daml_2_sdk_version: str,
    daml_3_sdk_version: str,
    cache_dir: Path,
    temp_dir: Optional[Path] = None,
) -> None:
    """
    Update the parts of the dazl codebase that are code-generated.

    :param daml_2_sdk_version:
        The Daml 2 SDK and Canton 2 version.

    :param daml_3_sdk_version:
        The Daml 3 SDK version.

    :param cache_dir:
        The directory where artifacts should be downloaded to. These files are kept around in order
        to make subsequent runs quicker.

    :param temp_dir:
        If ``None`` (the default), a temporary directory is created on the fly, and erased when the
        process finishes.

        If specified, temporary files are written to this directory. The directory's contents are
        cleared before running, and are NOT cleaned up afterwards in order to facilitate debugging.
    """
    logger.info("Updating protobuf files:")
    logger.info("    Daml 2 SDK version: %s", daml_2_sdk_version)
    logger.info("    Daml 3 SDK version: %s", daml_3_sdk_version)
    logger.info("    cache directory:  %s", cache_dir)
    if temp_dir is not None:
        logger.info("    temp directory:  %s", temp_dir)

    proto_pack = repo_root / ".cache" / "protos.pb"
    python_gen_dir = repo_root / "python" / "dazl" / "_gen"
    go_gen_dir = repo_root / "go" / "api"

    # grab the Daml protobufs and the Canton distribution; internally, this function
    # caches the downloaded files so that this function can be run over and over again
    # quickly
    downloads = download_dependencies(daml_2_sdk_version, daml_3_sdk_version, to=cache_dir)

    # prepare a single protos.pb file that contains definitions for everything we
    # wish to generate
    protopack.build(**asdict(downloads), to=proto_pack, cache_dir=temp_dir)

    # now generate our various files
    codegen.python_files(from_=proto_pack, to=python_gen_dir)
    codegen.go_files(from_=proto_pack, to=go_gen_dir)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import traffic_control_parameters_pb2 as _traffic_control_parameters_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OnboardingRestriction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ONBOARDING_RESTRICTION_UNSPECIFIED: _ClassVar[OnboardingRestriction]
    ONBOARDING_RESTRICTION_UNRESTRICTED_OPEN: _ClassVar[OnboardingRestriction]
    ONBOARDING_RESTRICTION_UNRESTRICTED_LOCKED: _ClassVar[OnboardingRestriction]
    ONBOARDING_RESTRICTION_RESTRICTED_OPEN: _ClassVar[OnboardingRestriction]
    ONBOARDING_RESTRICTION_RESTRICTED_LOCKED: _ClassVar[OnboardingRestriction]
ONBOARDING_RESTRICTION_UNSPECIFIED: OnboardingRestriction
ONBOARDING_RESTRICTION_UNRESTRICTED_OPEN: OnboardingRestriction
ONBOARDING_RESTRICTION_UNRESTRICTED_LOCKED: OnboardingRestriction
ONBOARDING_RESTRICTION_RESTRICTED_OPEN: OnboardingRestriction
ONBOARDING_RESTRICTION_RESTRICTED_LOCKED: OnboardingRestriction

class AcsCommitmentsCatchUpConfig(_message.Message):
    __slots__ = ("catchup_interval_skip", "nr_intervals_to_trigger_catchup")
    CATCHUP_INTERVAL_SKIP_FIELD_NUMBER: _ClassVar[int]
    NR_INTERVALS_TO_TRIGGER_CATCHUP_FIELD_NUMBER: _ClassVar[int]
    catchup_interval_skip: int
    nr_intervals_to_trigger_catchup: int
    def __init__(self, catchup_interval_skip: _Optional[int] = ..., nr_intervals_to_trigger_catchup: _Optional[int] = ...) -> None: ...

class ParticipantDomainLimits(_message.Message):
    __slots__ = ("confirmation_requests_max_rate", "max_num_parties", "max_num_packages")
    CONFIRMATION_REQUESTS_MAX_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_NUM_PARTIES_FIELD_NUMBER: _ClassVar[int]
    MAX_NUM_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    confirmation_requests_max_rate: int
    max_num_parties: int
    max_num_packages: int
    def __init__(self, confirmation_requests_max_rate: _Optional[int] = ..., max_num_parties: _Optional[int] = ..., max_num_packages: _Optional[int] = ...) -> None: ...

class DynamicDomainParameters(_message.Message):
    __slots__ = ("confirmation_response_timeout", "mediator_reaction_timeout", "transfer_exclusivity_timeout", "topology_change_delay", "ledger_time_record_time_tolerance", "reconciliation_interval", "mediator_deduplication_timeout", "max_request_size", "onboarding_restriction", "required_packages", "only_required_packages_permitted", "default_participant_limits", "default_max_hosting_participants_per_party", "sequencer_aggregate_submission_timeout", "traffic_control_parameters", "acs_commitments_catchup_config")
    CONFIRMATION_RESPONSE_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REACTION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_EXCLUSIVITY_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_CHANGE_DELAY_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIME_RECORD_TIME_TOLERANCE_FIELD_NUMBER: _ClassVar[int]
    RECONCILIATION_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_DEDUPLICATION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    MAX_REQUEST_SIZE_FIELD_NUMBER: _ClassVar[int]
    ONBOARDING_RESTRICTION_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    ONLY_REQUIRED_PACKAGES_PERMITTED_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_PARTICIPANT_LIMITS_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_MAX_HOSTING_PARTICIPANTS_PER_PARTY_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_AGGREGATE_SUBMISSION_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TRAFFIC_CONTROL_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    ACS_COMMITMENTS_CATCHUP_CONFIG_FIELD_NUMBER: _ClassVar[int]
    confirmation_response_timeout: _duration_pb2.Duration
    mediator_reaction_timeout: _duration_pb2.Duration
    transfer_exclusivity_timeout: _duration_pb2.Duration
    topology_change_delay: _duration_pb2.Duration
    ledger_time_record_time_tolerance: _duration_pb2.Duration
    reconciliation_interval: _duration_pb2.Duration
    mediator_deduplication_timeout: _duration_pb2.Duration
    max_request_size: int
    onboarding_restriction: OnboardingRestriction
    required_packages: _containers.RepeatedScalarFieldContainer[str]
    only_required_packages_permitted: bool
    default_participant_limits: ParticipantDomainLimits
    default_max_hosting_participants_per_party: int
    sequencer_aggregate_submission_timeout: _duration_pb2.Duration
    traffic_control_parameters: _traffic_control_parameters_pb2.TrafficControlParameters
    acs_commitments_catchup_config: AcsCommitmentsCatchUpConfig
    def __init__(self, confirmation_response_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., mediator_reaction_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., transfer_exclusivity_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., topology_change_delay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., ledger_time_record_time_tolerance: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., reconciliation_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., mediator_deduplication_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_request_size: _Optional[int] = ..., onboarding_restriction: _Optional[_Union[OnboardingRestriction, str]] = ..., required_packages: _Optional[_Iterable[str]] = ..., only_required_packages_permitted: bool = ..., default_participant_limits: _Optional[_Union[ParticipantDomainLimits, _Mapping]] = ..., default_max_hosting_participants_per_party: _Optional[int] = ..., sequencer_aggregate_submission_timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., traffic_control_parameters: _Optional[_Union[_traffic_control_parameters_pb2.TrafficControlParameters, _Mapping]] = ..., acs_commitments_catchup_config: _Optional[_Union[AcsCommitmentsCatchUpConfig, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from . import sequencing_pb2 as _sequencing_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyChangeOp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    Add: _ClassVar[TopologyChangeOp]
    Remove: _ClassVar[TopologyChangeOp]
    Replace: _ClassVar[TopologyChangeOp]

class TrustLevel(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingTrustLevel: _ClassVar[TrustLevel]
    Ordinary: _ClassVar[TrustLevel]
    Vip: _ClassVar[TrustLevel]

class ParticipantPermission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingParticipantPermission: _ClassVar[ParticipantPermission]
    Submission: _ClassVar[ParticipantPermission]
    Confirmation: _ClassVar[ParticipantPermission]
    Observation: _ClassVar[ParticipantPermission]
    Disabled: _ClassVar[ParticipantPermission]

class RequestSide(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingRequestSide: _ClassVar[RequestSide]
    Both: _ClassVar[RequestSide]
    From: _ClassVar[RequestSide]
    To: _ClassVar[RequestSide]
Add: TopologyChangeOp
Remove: TopologyChangeOp
Replace: TopologyChangeOp
MissingTrustLevel: TrustLevel
Ordinary: TrustLevel
Vip: TrustLevel
MissingParticipantPermission: ParticipantPermission
Submission: ParticipantPermission
Confirmation: ParticipantPermission
Observation: ParticipantPermission
Disabled: ParticipantPermission
MissingRequestSide: RequestSide
Both: RequestSide
From: RequestSide
To: RequestSide

class ParticipantState(_message.Message):
    __slots__ = ("side", "domain", "participant", "permission", "trust_level")
    SIDE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    TRUST_LEVEL_FIELD_NUMBER: _ClassVar[int]
    side: RequestSide
    domain: str
    participant: str
    permission: ParticipantPermission
    trust_level: TrustLevel
    def __init__(self, side: _Optional[_Union[RequestSide, str]] = ..., domain: _Optional[str] = ..., participant: _Optional[str] = ..., permission: _Optional[_Union[ParticipantPermission, str]] = ..., trust_level: _Optional[_Union[TrustLevel, str]] = ...) -> None: ...

class PartyToParticipant(_message.Message):
    __slots__ = ("side", "party", "participant", "permission")
    SIDE_FIELD_NUMBER: _ClassVar[int]
    PARTY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    side: RequestSide
    party: str
    participant: str
    permission: ParticipantPermission
    def __init__(self, side: _Optional[_Union[RequestSide, str]] = ..., party: _Optional[str] = ..., participant: _Optional[str] = ..., permission: _Optional[_Union[ParticipantPermission, str]] = ...) -> None: ...

class MediatorDomainState(_message.Message):
    __slots__ = ("side", "domain", "mediator")
    SIDE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_FIELD_NUMBER: _ClassVar[int]
    side: RequestSide
    domain: str
    mediator: str
    def __init__(self, side: _Optional[_Union[RequestSide, str]] = ..., domain: _Optional[str] = ..., mediator: _Optional[str] = ...) -> None: ...

class NamespaceDelegation(_message.Message):
    __slots__ = ("namespace", "target_key", "is_root_delegation")
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TARGET_KEY_FIELD_NUMBER: _ClassVar[int]
    IS_ROOT_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    target_key: _crypto_pb2.SigningPublicKey
    is_root_delegation: bool
    def __init__(self, namespace: _Optional[str] = ..., target_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ..., is_root_delegation: bool = ...) -> None: ...

class IdentifierDelegation(_message.Message):
    __slots__ = ("unique_identifier", "target_key")
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    TARGET_KEY_FIELD_NUMBER: _ClassVar[int]
    unique_identifier: str
    target_key: _crypto_pb2.SigningPublicKey
    def __init__(self, unique_identifier: _Optional[str] = ..., target_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ...) -> None: ...

class OwnerToKeyMapping(_message.Message):
    __slots__ = ("key_owner", "public_key")
    KEY_OWNER_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    key_owner: str
    public_key: _crypto_pb2.PublicKey
    def __init__(self, key_owner: _Optional[str] = ..., public_key: _Optional[_Union[_crypto_pb2.PublicKey, _Mapping]] = ...) -> None: ...

class SignedLegalIdentityClaim(_message.Message):
    __slots__ = ("claim", "signature")
    CLAIM_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    claim: bytes
    signature: _crypto_pb2.Signature
    def __init__(self, claim: _Optional[bytes] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class LegalIdentityClaim(_message.Message):
    __slots__ = ("unique_identifier", "x509_cert")
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    X509_CERT_FIELD_NUMBER: _ClassVar[int]
    unique_identifier: str
    x509_cert: bytes
    def __init__(self, unique_identifier: _Optional[str] = ..., x509_cert: _Optional[bytes] = ...) -> None: ...

class VettedPackages(_message.Message):
    __slots__ = ("participant", "package_ids")
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_IDS_FIELD_NUMBER: _ClassVar[int]
    participant: str
    package_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, participant: _Optional[str] = ..., package_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class TopologyStateUpdate(_message.Message):
    __slots__ = ("operation", "id", "namespace_delegation", "identifier_delegation", "owner_to_key_mapping", "party_to_participant", "signed_legal_identity_claim", "participant_state", "vetted_packages", "mediator_domain_state")
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    OWNER_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    SIGNED_LEGAL_IDENTITY_CLAIM_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_STATE_FIELD_NUMBER: _ClassVar[int]
    VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_DOMAIN_STATE_FIELD_NUMBER: _ClassVar[int]
    operation: TopologyChangeOp
    id: str
    namespace_delegation: NamespaceDelegation
    identifier_delegation: IdentifierDelegation
    owner_to_key_mapping: OwnerToKeyMapping
    party_to_participant: PartyToParticipant
    signed_legal_identity_claim: SignedLegalIdentityClaim
    participant_state: ParticipantState
    vetted_packages: VettedPackages
    mediator_domain_state: MediatorDomainState
    def __init__(self, operation: _Optional[_Union[TopologyChangeOp, str]] = ..., id: _Optional[str] = ..., namespace_delegation: _Optional[_Union[NamespaceDelegation, _Mapping]] = ..., identifier_delegation: _Optional[_Union[IdentifierDelegation, _Mapping]] = ..., owner_to_key_mapping: _Optional[_Union[OwnerToKeyMapping, _Mapping]] = ..., party_to_participant: _Optional[_Union[PartyToParticipant, _Mapping]] = ..., signed_legal_identity_claim: _Optional[_Union[SignedLegalIdentityClaim, _Mapping]] = ..., participant_state: _Optional[_Union[ParticipantState, _Mapping]] = ..., vetted_packages: _Optional[_Union[VettedPackages, _Mapping]] = ..., mediator_domain_state: _Optional[_Union[MediatorDomainState, _Mapping]] = ...) -> None: ...

class DomainParametersChange(_message.Message):
    __slots__ = ("domain", "domain_parameters")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    domain_parameters: _sequencing_pb2.DynamicDomainParameters
    def __init__(self, domain: _Optional[str] = ..., domain_parameters: _Optional[_Union[_sequencing_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...

class DomainGovernanceTransaction(_message.Message):
    __slots__ = ("domain_parameters_change",)
    DOMAIN_PARAMETERS_CHANGE_FIELD_NUMBER: _ClassVar[int]
    domain_parameters_change: DomainParametersChange
    def __init__(self, domain_parameters_change: _Optional[_Union[DomainParametersChange, _Mapping]] = ...) -> None: ...

class TopologyTransaction(_message.Message):
    __slots__ = ("state_update", "domain_governance")
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    state_update: TopologyStateUpdate
    domain_governance: DomainGovernanceTransaction
    def __init__(self, state_update: _Optional[_Union[TopologyStateUpdate, _Mapping]] = ..., domain_governance: _Optional[_Union[DomainGovernanceTransaction, _Mapping]] = ...) -> None: ...

class SignedTopologyTransaction(_message.Message):
    __slots__ = ("transaction", "key", "signature")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    transaction: bytes
    key: _crypto_pb2.SigningPublicKey
    signature: _crypto_pb2.Signature
    def __init__(self, transaction: _Optional[bytes] = ..., key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class DomainTopologyTransactionMessage(_message.Message):
    __slots__ = ("signature", "domain_id", "transactions")
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    signature: _crypto_pb2.Signature
    domain_id: str
    transactions: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., domain_id: _Optional[str] = ..., transactions: _Optional[_Iterable[bytes]] = ...) -> None: ...

class RegisterTopologyTransactionRequest(_message.Message):
    __slots__ = ("requested_by", "participant", "request_id", "signed_topology_transactions", "domain_id")
    REQUESTED_BY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNED_TOPOLOGY_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    requested_by: str
    participant: str
    request_id: str
    signed_topology_transactions: _containers.RepeatedScalarFieldContainer[bytes]
    domain_id: str
    def __init__(self, requested_by: _Optional[str] = ..., participant: _Optional[str] = ..., request_id: _Optional[str] = ..., signed_topology_transactions: _Optional[_Iterable[bytes]] = ..., domain_id: _Optional[str] = ...) -> None: ...

class RegisterTopologyTransactionResponse(_message.Message):
    __slots__ = ("requested_by", "participant", "request_id", "results", "domain_id")
    class Result(_message.Message):
        __slots__ = ("unique_path", "state", "error_message")
        class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            MISSING_STATE: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            REQUESTED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            FAILED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            REJECTED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            ACCEPTED: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            DUPLICATE: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
            OBSOLETE: _ClassVar[RegisterTopologyTransactionResponse.Result.State]
        MISSING_STATE: RegisterTopologyTransactionResponse.Result.State
        REQUESTED: RegisterTopologyTransactionResponse.Result.State
        FAILED: RegisterTopologyTransactionResponse.Result.State
        REJECTED: RegisterTopologyTransactionResponse.Result.State
        ACCEPTED: RegisterTopologyTransactionResponse.Result.State
        DUPLICATE: RegisterTopologyTransactionResponse.Result.State
        OBSOLETE: RegisterTopologyTransactionResponse.Result.State
        UNIQUE_PATH_FIELD_NUMBER: _ClassVar[int]
        STATE_FIELD_NUMBER: _ClassVar[int]
        ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        unique_path: str
        state: RegisterTopologyTransactionResponse.Result.State
        error_message: str
        def __init__(self, unique_path: _Optional[str] = ..., state: _Optional[_Union[RegisterTopologyTransactionResponse.Result.State, str]] = ..., error_message: _Optional[str] = ...) -> None: ...
    REQUESTED_BY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    requested_by: str
    participant: str
    request_id: str
    results: _containers.RepeatedCompositeFieldContainer[RegisterTopologyTransactionResponse.Result]
    domain_id: str
    def __init__(self, requested_by: _Optional[str] = ..., participant: _Optional[str] = ..., request_id: _Optional[str] = ..., results: _Optional[_Iterable[_Union[RegisterTopologyTransactionResponse.Result, _Mapping]]] = ..., domain_id: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTimeModelRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTimeModelResponse(_message.Message):
    __slots__ = ("configuration_generation", "time_model")
    CONFIGURATION_GENERATION_FIELD_NUMBER: _ClassVar[int]
    TIME_MODEL_FIELD_NUMBER: _ClassVar[int]
    configuration_generation: int
    time_model: TimeModel
    def __init__(self, configuration_generation: _Optional[int] = ..., time_model: _Optional[_Union[TimeModel, _Mapping]] = ...) -> None: ...

class SetTimeModelRequest(_message.Message):
    __slots__ = ("submission_id", "maximum_record_time", "configuration_generation", "new_time_model")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_GENERATION_FIELD_NUMBER: _ClassVar[int]
    NEW_TIME_MODEL_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    maximum_record_time: _timestamp_pb2.Timestamp
    configuration_generation: int
    new_time_model: TimeModel
    def __init__(self, submission_id: _Optional[str] = ..., maximum_record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., configuration_generation: _Optional[int] = ..., new_time_model: _Optional[_Union[TimeModel, _Mapping]] = ...) -> None: ...

class SetTimeModelResponse(_message.Message):
    __slots__ = ("configuration_generation",)
    CONFIGURATION_GENERATION_FIELD_NUMBER: _ClassVar[int]
    configuration_generation: int
    def __init__(self, configuration_generation: _Optional[int] = ...) -> None: ...

class TimeModel(_message.Message):
    __slots__ = ("avg_transaction_latency", "min_skew", "max_skew")
    AVG_TRANSACTION_LATENCY_FIELD_NUMBER: _ClassVar[int]
    MIN_SKEW_FIELD_NUMBER: _ClassVar[int]
    MAX_SKEW_FIELD_NUMBER: _ClassVar[int]
    avg_transaction_latency: _duration_pb2.Duration
    min_skew: _duration_pb2.Duration
    max_skew: _duration_pb2.Duration
    def __init__(self, avg_transaction_latency: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., min_skew: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_skew: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

"""
Internal utilities for maintaining this codebase.

The symbols in this module are NOT part of the public APIs, and will be changed without notice!
"""

# TODO: read this directly from go.mod
dazl_go_module = "github.com/digital-asset/dazl-client/v8"



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/sequencing.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/sequencing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ...v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5com/digitalasset/canton/protocol/v30/sequencing.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"\x83\x02\n\x1dPossiblyIgnoredSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12N\n\rtrace_context\x18\x03 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\x12\x1d\n\nis_ignored\x18\x04 \x01(\x08R\tisIgnored\x12;\n\nunderlying\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\nunderlying\"\x82\x01\n\x0eRecipientsTree\x12\x1e\n\nrecipients\x18\x01 \x03(\tR\nrecipients\x12P\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x08\x63hildren\"k\n\nRecipients\x12]\n\x0frecipients_tree\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x0erecipientsTree\"A\n\x10ServiceAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nlegal_text\x18\x02 \x01(\tR\tlegalText\"\xcf\x03\n\tHandshake\x1a\x9b\x01\n\x07Request\x12\x38\n\x18\x63lient_protocol_versions\x18\x01 \x03(\tR\x16\x63lientProtocolVersions\x12V\n\x18minimum_protocol_version\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x16minimumProtocolVersion\x1a\xf5\x01\n\x08Response\x12\x36\n\x17server_protocol_version\x18\x01 \x01(\tR\x15serverProtocolVersion\x12S\n\x07success\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.Handshake.SuccessH\x00R\x07success\x12S\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.Handshake.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1a\t\n\x07Success\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\".\n\x18SequencingSubmissionCost\x12\x12\n\x04\x63ost\x18\x01 \x01(\x03R\x04\x63ost\"|\n\x15SinglePartySignatures\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"n\n\x0fPartySignatures\x12[\n\nsignatures\x18\x01 \x03(\x0b\x32;.com.digitalasset.canton.protocol.v30.SinglePartySignaturesR\nsignatures\"\x91\x05\n\x16StaticDomainParameters\x12u\n\x1crequired_signing_key_schemes\x18\x01 \x03(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\x19requiredSigningKeySchemes\x12w\n\x19required_encryption_specs\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.crypto.v30.RequiredEncryptionSpecsR\x17requiredEncryptionSpecs\x12{\n\x1erequired_symmetric_key_schemes\x18\x03 \x03(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x1brequiredSymmetricKeySchemes\x12k\n\x18required_hash_algorithms\x18\x04 \x03(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HashAlgorithmR\x16requiredHashAlgorithms\x12r\n\x1brequired_crypto_key_formats\x18\x05 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x18requiredCryptoKeyFormats\x12)\n\x10protocol_version\x18\x06 \x01(\x05R\x0fprotocolVersion\"\xc5\x01\n\x08\x45nvelope\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12P\n\nrecipients\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v30.RecipientsR\nrecipients\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"U\n\x05\x42\x61tch\x12L\n\tenvelopes\x18\x01 \x03(\x0b\x32..com.digitalasset.canton.protocol.v30.EnvelopeR\tenvelopes\"\x85\x02\n\x0f\x43ompressedBatch\x12h\n\talgorithm\x18\x01 \x01(\x0e\x32J.com.digitalasset.canton.protocol.v30.CompressedBatch.CompressionAlgorithmR\talgorithm\x12)\n\x10\x63ompressed_batch\x18\x02 \x01(\x0cR\x0f\x63ompressedBatch\"]\n\x14\x43ompressionAlgorithm\x12%\n!COMPRESSION_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OMPRESSION_ALGORITHM_GZIP\x10\x01\"\xe0\x03\n\x0eSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\nmessage_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tmessageId\x12K\n\x05\x62\x61tch\x18\x05 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12\x44\n\x14\x64\x65liver_error_reason\x18\x06 \x01(\x0b\x32\x12.google.rpc.StatusR\x12\x64\x65liverErrorReason\x12J\n\x12topology_timestamp\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11topologyTimestamp\x12]\n\x0ftraffic_receipt\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.TrafficReceiptR\x0etrafficReceipt\"\xde\x03\n\x11SubmissionRequest\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\x12K\n\x05\x62\x61tch\x18\x04 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12.\n\x13max_sequencing_time\x18\x05 \x01(\x03R\x11maxSequencingTime\x12J\n\x12topology_timestamp\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11topologyTimestamp\x12`\n\x10\x61ggregation_rule\x18\x07 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.AggregationRuleR\x0f\x61ggregationRule\x12g\n\x0fsubmission_cost\x18\x08 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.SequencingSubmissionCostR\x0esubmissionCostBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.sequencing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_start=380
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_end=639
  _globals['_RECIPIENTSTREE']._serialized_start=642
  _globals['_RECIPIENTSTREE']._serialized_end=772
  _globals['_RECIPIENTS']._serialized_start=774
  _globals['_RECIPIENTS']._serialized_end=881
  _globals['_SERVICEAGREEMENT']._serialized_start=883
  _globals['_SERVICEAGREEMENT']._serialized_end=948
  _globals['_HANDSHAKE']._serialized_start=951
  _globals['_HANDSHAKE']._serialized_end=1414
  _globals['_HANDSHAKE_REQUEST']._serialized_start=965
  _globals['_HANDSHAKE_REQUEST']._serialized_end=1120
  _globals['_HANDSHAKE_RESPONSE']._serialized_start=1123
  _globals['_HANDSHAKE_RESPONSE']._serialized_end=1368
  _globals['_HANDSHAKE_SUCCESS']._serialized_start=1370
  _globals['_HANDSHAKE_SUCCESS']._serialized_end=1379
  _globals['_HANDSHAKE_FAILURE']._serialized_start=1381
  _globals['_HANDSHAKE_FAILURE']._serialized_end=1414
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_start=1416
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_end=1462
  _globals['_SINGLEPARTYSIGNATURES']._serialized_start=1464
  _globals['_SINGLEPARTYSIGNATURES']._serialized_end=1588
  _globals['_PARTYSIGNATURES']._serialized_start=1590
  _globals['_PARTYSIGNATURES']._serialized_end=1700
  _globals['_STATICDOMAINPARAMETERS']._serialized_start=1703
  _globals['_STATICDOMAINPARAMETERS']._serialized_end=2360
  _globals['_ENVELOPE']._serialized_start=2363
  _globals['_ENVELOPE']._serialized_end=2560
  _globals['_BATCH']._serialized_start=2562
  _globals['_BATCH']._serialized_end=2647
  _globals['_COMPRESSEDBATCH']._serialized_start=2650
  _globals['_COMPRESSEDBATCH']._serialized_end=2911
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_start=2818
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_end=2911
  _globals['_SEQUENCEDEVENT']._serialized_start=2914
  _globals['_SEQUENCEDEVENT']._serialized_end=3394
  _globals['_SUBMISSIONREQUEST']._serialized_start=3397
  _globals['_SUBMISSIONREQUEST']._serialized_end=3875
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import base64
import json
from typing import Any, Mapping, Optional

from dazl.ledger.auth import V1TokenNamespace
from dazl.prim import Parties

__all__ = ["encode_unsigned_token"]


def encode_unsigned_token(
    *,
    user_id: Optional[str] = None,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    ledger_id: Optional[str] = None,
    application_id: Optional[str] = None,
    admin: Optional[bool] = None,
) -> bytes:
    """
    Generate a JSON Web Token (JWT) that has no signature.

    Because this JWT has no signature, it is really only useful in a testing context. Do not use
    to generate tokens against a real ledger!

    :param user_id:
    :param read_as:
        If specified, generates a Daml V1 token with the specified read-as values.
    :param act_as:
        If specified, generates a Daml V1 token with the specified act-as values.
    :param ledger_id:
        If specified, generates a Daml V1 token with the specified ledger ID value.
    :param application_id:
    :param admin:
    :return:
    """
    header = {
        "alg": "none",
        "typ": "JWT",
    }
    payload = {V1TokenNamespace: {}}  # type: Mapping[str, Any]
    if ledger_id is not None:
        payload[V1TokenNamespace]["ledgerId"] = ledger_id
    if application_id is not None:
        payload[V1TokenNamespace]["applicationId"] = application_id
    if act_as is not None:
        payload[V1TokenNamespace]["actAs"] = sorted(act_as)
    if read_as is not None:
        payload[V1TokenNamespace]["readAs"] = sorted(read_as)
    if admin:
        payload[V1TokenNamespace]["admin"] = admin

    return (
        base64.urlsafe_b64encode(json.dumps(header).encode("utf-8")).rstrip(b"=")
        + b"."
        + base64.urlsafe_b64encode(json.dumps(payload).encode("utf-8")).rstrip(b"=")
        + b"."
    )



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
Utilities for dealing with the file system.
"""

from __future__ import annotations

import socket

__all__ = ["find_free_port", "is_port_alive"]


def find_free_port() -> int:
    sock = socket.socket()
    try:
        sock.bind(("", 0))
        return sock.getsockname()[1]
    finally:
        sock.close()


def is_port_alive(port: int) -> bool:
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    try:
        result = sock.connect_ex(("127.0.0.1", port))
        return result == 0
    finally:
        sock.close()



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/enterprise_mediator_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/enterprise_mediator_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....pruning.admin.v0 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_pruning_dot_admin_dot_v0_dot_pruning__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXcom/digitalasset/canton/domain/admin/v0/enterprise_mediator_administration_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a\x36\x63om/digitalasset/canton/pruning/admin/v0/pruning.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"R\n\x16MediatorPruningRequest\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp2\x9b\t\n\'EnterpriseMediatorAdministrationService\x12`\n\x05Prune\x12?.com.digitalasset.canton.domain.admin.v0.MediatorPruningRequest\x1a\x16.google.protobuf.Empty\x12\x8c\x01\n\x0bSetSchedule\x12=.com.digitalasset.canton.pruning.admin.v0.SetSchedule.Request\x1a>.com.digitalasset.canton.pruning.admin.v0.SetSchedule.Response\x12\x80\x01\n\x07SetCron\x12\x39.com.digitalasset.canton.pruning.admin.v0.SetCron.Request\x1a:.com.digitalasset.canton.pruning.admin.v0.SetCron.Response\x12\x95\x01\n\x0eSetMaxDuration\x12@.com.digitalasset.canton.pruning.admin.v0.SetMaxDuration.Request\x1a\x41.com.digitalasset.canton.pruning.admin.v0.SetMaxDuration.Response\x12\x8f\x01\n\x0cSetRetention\x12>.com.digitalasset.canton.pruning.admin.v0.SetRetention.Request\x1a?.com.digitalasset.canton.pruning.admin.v0.SetRetention.Response\x12\x92\x01\n\rClearSchedule\x12?.com.digitalasset.canton.pruning.admin.v0.ClearSchedule.Request\x1a@.com.digitalasset.canton.pruning.admin.v0.ClearSchedule.Response\x12\x8c\x01\n\x0bGetSchedule\x12=.com.digitalasset.canton.pruning.admin.v0.GetSchedule.Request\x1a>.com.digitalasset.canton.pruning.admin.v0.GetSchedule.Response\x12\xad\x01\n\x16LocatePruningTimestamp\x12H.com.digitalasset.canton.pruning.admin.v0.LocatePruningTimestamp.Request\x1aI.com.digitalasset.canton.pruning.admin.v0.LocatePruningTimestamp.ResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.enterprise_mediator_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_MEDIATORPRUNINGREQUEST']._serialized_start=251
  _globals['_MEDIATORPRUNINGREQUEST']._serialized_end=333
  _globals['_ENTERPRISEMEDIATORADMINISTRATIONSERVICE']._serialized_start=336
  _globals['_ENTERPRISEMEDIATORADMINISTRATIONSERVICE']._serialized_end=1515
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/package_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/package_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,com/daml/ledger/api/v2/package_service.proto\x12\x16\x63om.daml.ledger.api.v2\"7\n\x14ListPackagesResponse\x12\x1f\n\x0bpackage_ids\x18\x01 \x03(\tR\npackageIds\"\x9c\x01\n\x12GetPackageResponse\x12I\n\rhash_function\x18\x01 \x01(\x0e\x32$.com.daml.ledger.api.v2.HashFunctionR\x0chashFunction\x12\'\n\x0f\x61rchive_payload\x18\x02 \x01(\x0cR\x0e\x61rchivePayload\x12\x12\n\x04hash\x18\x03 \x01(\tR\x04hash\"h\n\x18GetPackageStatusResponse\x12L\n\x0epackage_status\x18\x01 \x01(\x0e\x32%.com.daml.ledger.api.v2.PackageStatusR\rpackageStatus\"\x15\n\x13ListPackagesRequest\"2\n\x11GetPackageRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\"8\n\x17GetPackageStatusRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId*N\n\rPackageStatus\x12\x1e\n\x1aPACKAGE_STATUS_UNSPECIFIED\x10\x00\x12\x1d\n\x19PACKAGE_STATUS_REGISTERED\x10\x01*(\n\x0cHashFunction\x12\x18\n\x14HASH_FUNCTION_SHA256\x10\x00\x32\xd7\x02\n\x0ePackageService\x12i\n\x0cListPackages\x12+.com.daml.ledger.api.v2.ListPackagesRequest\x1a,.com.daml.ledger.api.v2.ListPackagesResponse\x12\x63\n\nGetPackage\x12).com.daml.ledger.api.v2.GetPackageRequest\x1a*.com.daml.ledger.api.v2.GetPackageResponse\x12u\n\x10GetPackageStatus\x12/.com.daml.ledger.api.v2.GetPackageStatusRequest\x1a\x30.com.daml.ledger.api.v2.GetPackageStatusResponseB\x92\x01\n\x16\x63om.daml.ledger.api.v2B\x18PackageServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.package_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\030PackageServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_PACKAGESTATUS']._serialized_start=527
  _globals['_PACKAGESTATUS']._serialized_end=605
  _globals['_HASHFUNCTION']._serialized_start=607
  _globals['_HASHFUNCTION']._serialized_end=647
  _globals['_LISTPACKAGESRESPONSE']._serialized_start=72
  _globals['_LISTPACKAGESRESPONSE']._serialized_end=127
  _globals['_GETPACKAGERESPONSE']._serialized_start=130
  _globals['_GETPACKAGERESPONSE']._serialized_end=286
  _globals['_GETPACKAGESTATUSRESPONSE']._serialized_start=288
  _globals['_GETPACKAGESTATUSRESPONSE']._serialized_end=392
  _globals['_LISTPACKAGESREQUEST']._serialized_start=394
  _globals['_LISTPACKAGESREQUEST']._serialized_end=415
  _globals['_GETPACKAGEREQUEST']._serialized_start=417
  _globals['_GETPACKAGEREQUEST']._serialized_end=467
  _globals['_GETPACKAGESTATUSREQUEST']._serialized_start=469
  _globals['_GETPACKAGESTATUSREQUEST']._serialized_end=525
  _globals['_PACKAGESERVICE']._serialized_start=650
  _globals['_PACKAGESERVICE']._serialized_end=993
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v0/sequencer_authentication_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v0/sequencer_authentication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/domain/api/v0/sequencer_authentication_service.proto\x12%com.digitalasset.canton.domain.api.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcd\x03\n\tChallenge\x1a[\n\x07Request\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x38\n\x18member_protocol_versions\x18\x02 \x03(\tR\x16memberProtocolVersions\x1a\xbf\x01\n\x08Response\x12T\n\x07success\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.domain.api.v0.Challenge.SuccessH\x00R\x07success\x12T\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.domain.api.v0.Challenge.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1aj\n\x07Success\x12%\n\x0e\x64omain_version\x18\x01 \x01(\tR\rdomainVersion\x12\x14\n\x05nonce\x18\x02 \x01(\x0cR\x05nonce\x12\"\n\x0c\x66ingerprints\x18\x03 \x03(\tR\x0c\x66ingerprints\x1a\x35\n\x07\x46\x61ilure\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"\xf5\x03\n\x0e\x41uthentication\x1a\x83\x01\n\x07Request\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12J\n\tsignature\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\tsignature\x12\x14\n\x05nonce\x18\x03 \x01(\x0cR\x05nonce\x1a\xc9\x01\n\x08Response\x12Y\n\x07success\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.domain.api.v0.Authentication.SuccessH\x00R\x07success\x12Y\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.domain.api.v0.Authentication.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1aZ\n\x07Success\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x12\x39\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x1a\x35\n\x07\x46\x61ilure\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason2\xb7\x02\n\x1eSequencerAuthenticationService\x12\x82\x01\n\tChallenge\x12\x38.com.digitalasset.canton.domain.api.v0.Challenge.Request\x1a\x39.com.digitalasset.canton.domain.api.v0.Challenge.Response\"\x00\x12\x8f\x01\n\x0c\x41uthenticate\x12=.com.digitalasset.canton.domain.api.v0.Authentication.Request\x1a>.com.digitalasset.canton.domain.api.v0.Authentication.Response\"\x00\x42VZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v0.sequencer_authentication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZTgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v0'
  _globals['_CHALLENGE']._serialized_start=201
  _globals['_CHALLENGE']._serialized_end=662
  _globals['_CHALLENGE_REQUEST']._serialized_start=214
  _globals['_CHALLENGE_REQUEST']._serialized_end=305
  _globals['_CHALLENGE_RESPONSE']._serialized_start=308
  _globals['_CHALLENGE_RESPONSE']._serialized_end=499
  _globals['_CHALLENGE_SUCCESS']._serialized_start=501
  _globals['_CHALLENGE_SUCCESS']._serialized_end=607
  _globals['_CHALLENGE_FAILURE']._serialized_start=609
  _globals['_CHALLENGE_FAILURE']._serialized_end=662
  _globals['_AUTHENTICATION']._serialized_start=665
  _globals['_AUTHENTICATION']._serialized_end=1166
  _globals['_AUTHENTICATION_REQUEST']._serialized_start=684
  _globals['_AUTHENTICATION_REQUEST']._serialized_end=815
  _globals['_AUTHENTICATION_RESPONSE']._serialized_start=818
  _globals['_AUTHENTICATION_RESPONSE']._serialized_end=1019
  _globals['_AUTHENTICATION_SUCCESS']._serialized_start=1021
  _globals['_AUTHENTICATION_SUCCESS']._serialized_end=1111
  _globals['_AUTHENTICATION_FAILURE']._serialized_start=609
  _globals['_AUTHENTICATION_FAILURE']._serialized_end=662
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_start=1169
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_end=1480
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/pruning_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/pruning_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....pruning.admin.v0 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_pruning_dot_admin_dot_v0_dot_pruning__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBcom/digitalasset/canton/participant/admin/v0/pruning_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a\x36\x63om/digitalasset/canton/pruning/admin/v0/pruning.proto\x1a\x1fgoogle/protobuf/timestamp.proto\".\n\x0cPruneRequest\x12\x1e\n\x0bprune_up_to\x18\x01 \x01(\tR\tpruneUpTo\"\x0f\n\rPruneResponse\"z\n\x1bGetSafePruningOffsetRequest\x12<\n\x0c\x62\x65\x66ore_or_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nbeforeOrAt\x12\x1d\n\nledger_end\x18\x02 \x01(\tR\tledgerEnd\"\x8b\x02\n\x1cGetSafePruningOffsetResponse\x12\x30\n\x13safe_pruning_offset\x18\x01 \x01(\tH\x00R\x11safePruningOffset\x12\x95\x01\n\x16no_safe_pruning_offset\x18\x02 \x01(\x0b\x32^.com.digitalasset.canton.participant.admin.v0.GetSafePruningOffsetResponse.NoSafePruningOffsetH\x00R\x13noSafePruningOffset\x1a\x15\n\x13NoSafePruningOffsetB\n\n\x08response2\x83\x0c\n\x0ePruningService\x12\x80\x01\n\x05Prune\x12:.com.digitalasset.canton.participant.admin.v0.PruneRequest\x1a;.com.digitalasset.canton.participant.admin.v0.PruneResponse\x12\xad\x01\n\x14GetSafePruningOffset\x12I.com.digitalasset.canton.participant.admin.v0.GetSafePruningOffsetRequest\x1aJ.com.digitalasset.canton.participant.admin.v0.GetSafePruningOffsetResponse\x12\x8c\x01\n\x0bSetSchedule\x12=.com.digitalasset.canton.pruning.admin.v0.SetSchedule.Request\x1a>.com.digitalasset.canton.pruning.admin.v0.SetSchedule.Response\x12\xad\x01\n\x16SetParticipantSchedule\x12H.com.digitalasset.canton.pruning.admin.v0.SetParticipantSchedule.Request\x1aI.com.digitalasset.canton.pruning.admin.v0.SetParticipantSchedule.Response\x12\x80\x01\n\x07SetCron\x12\x39.com.digitalasset.canton.pruning.admin.v0.SetCron.Request\x1a:.com.digitalasset.canton.pruning.admin.v0.SetCron.Response\x12\x95\x01\n\x0eSetMaxDuration\x12@.com.digitalasset.canton.pruning.admin.v0.SetMaxDuration.Request\x1a\x41.com.digitalasset.canton.pruning.admin.v0.SetMaxDuration.Response\x12\x8f\x01\n\x0cSetRetention\x12>.com.digitalasset.canton.pruning.admin.v0.SetRetention.Request\x1a?.com.digitalasset.canton.pruning.admin.v0.SetRetention.Response\x12\x92\x01\n\rClearSchedule\x12?.com.digitalasset.canton.pruning.admin.v0.ClearSchedule.Request\x1a@.com.digitalasset.canton.pruning.admin.v0.ClearSchedule.Response\x12\x8c\x01\n\x0bGetSchedule\x12=.com.digitalasset.canton.pruning.admin.v0.GetSchedule.Request\x1a>.com.digitalasset.canton.pruning.admin.v0.GetSchedule.Response\x12\xad\x01\n\x16GetParticipantSchedule\x12H.com.digitalasset.canton.pruning.admin.v0.GetParticipantSchedule.Request\x1aI.com.digitalasset.canton.pruning.admin.v0.GetParticipantSchedule.ResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.pruning_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_PRUNEREQUEST']._serialized_start=205
  _globals['_PRUNEREQUEST']._serialized_end=251
  _globals['_PRUNERESPONSE']._serialized_start=253
  _globals['_PRUNERESPONSE']._serialized_end=268
  _globals['_GETSAFEPRUNINGOFFSETREQUEST']._serialized_start=270
  _globals['_GETSAFEPRUNINGOFFSETREQUEST']._serialized_end=392
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE']._serialized_start=395
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE']._serialized_end=662
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE_NOSAFEPRUNINGOFFSET']._serialized_start=629
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE_NOSAFEPRUNINGOFFSET']._serialized_end=650
  _globals['_PRUNINGSERVICE']._serialized_start=665
  _globals['_PRUNINGSERVICE']._serialized_end=2204
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import value_pb2 as _value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PreparedTransaction(_message.Message):
    __slots__ = ("transaction", "metadata")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    transaction: DamlTransaction
    metadata: Metadata
    def __init__(self, transaction: _Optional[_Union[DamlTransaction, _Mapping]] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("submitter_info", "submission_seed", "submission_time", "used_packages", "node_seeds", "global_key_mapping", "disclosed_events", "ledger_effective_time", "workflow_id", "interpretation_time_nanos", "domain_id", "mediator_group", "transaction_id")
    class SubmitterInfo(_message.Message):
        __slots__ = ("act_as", "read_as", "command_id")
        ACT_AS_FIELD_NUMBER: _ClassVar[int]
        READ_AS_FIELD_NUMBER: _ClassVar[int]
        COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
        act_as: _containers.RepeatedScalarFieldContainer[str]
        read_as: _containers.RepeatedScalarFieldContainer[str]
        command_id: str
        def __init__(self, act_as: _Optional[_Iterable[str]] = ..., read_as: _Optional[_Iterable[str]] = ..., command_id: _Optional[str] = ...) -> None: ...
    class NodeSeed(_message.Message):
        __slots__ = ("node_id", "seed")
        NODE_ID_FIELD_NUMBER: _ClassVar[int]
        SEED_FIELD_NUMBER: _ClassVar[int]
        node_id: int
        seed: bytes
        def __init__(self, node_id: _Optional[int] = ..., seed: _Optional[bytes] = ...) -> None: ...
    class GlobalKeyMappingEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: GlobalKey
        value: _value_pb2.Value
        def __init__(self, key: _Optional[_Union[GlobalKey, _Mapping]] = ..., value: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...
    class ProcessedDisclosedContract(_message.Message):
        __slots__ = ("contract", "created_at", "driver_metadata")
        CONTRACT_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        DRIVER_METADATA_FIELD_NUMBER: _ClassVar[int]
        contract: Create
        created_at: int
        driver_metadata: bytes
        def __init__(self, contract: _Optional[_Union[Create, _Mapping]] = ..., created_at: _Optional[int] = ..., driver_metadata: _Optional[bytes] = ...) -> None: ...
    SUBMITTER_INFO_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_SEED_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_TIME_FIELD_NUMBER: _ClassVar[int]
    USED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    NODE_SEEDS_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    DISCLOSED_EVENTS_FIELD_NUMBER: _ClassVar[int]
    LEDGER_EFFECTIVE_TIME_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    INTERPRETATION_TIME_NANOS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    submitter_info: Metadata.SubmitterInfo
    submission_seed: bytes
    submission_time: int
    used_packages: _containers.RepeatedScalarFieldContainer[str]
    node_seeds: _containers.RepeatedCompositeFieldContainer[Metadata.NodeSeed]
    global_key_mapping: _containers.RepeatedCompositeFieldContainer[Metadata.GlobalKeyMappingEntry]
    disclosed_events: _containers.RepeatedCompositeFieldContainer[Metadata.ProcessedDisclosedContract]
    ledger_effective_time: int
    workflow_id: str
    interpretation_time_nanos: int
    domain_id: str
    mediator_group: int
    transaction_id: str
    def __init__(self, submitter_info: _Optional[_Union[Metadata.SubmitterInfo, _Mapping]] = ..., submission_seed: _Optional[bytes] = ..., submission_time: _Optional[int] = ..., used_packages: _Optional[_Iterable[str]] = ..., node_seeds: _Optional[_Iterable[_Union[Metadata.NodeSeed, _Mapping]]] = ..., global_key_mapping: _Optional[_Iterable[_Union[Metadata.GlobalKeyMappingEntry, _Mapping]]] = ..., disclosed_events: _Optional[_Iterable[_Union[Metadata.ProcessedDisclosedContract, _Mapping]]] = ..., ledger_effective_time: _Optional[int] = ..., workflow_id: _Optional[str] = ..., interpretation_time_nanos: _Optional[int] = ..., domain_id: _Optional[str] = ..., mediator_group: _Optional[int] = ..., transaction_id: _Optional[str] = ...) -> None: ...

class DamlTransaction(_message.Message):
    __slots__ = ("version", "roots", "nodes")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ROOTS_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    version: str
    roots: _containers.RepeatedScalarFieldContainer[str]
    nodes: _containers.RepeatedCompositeFieldContainer[Node]
    def __init__(self, version: _Optional[str] = ..., roots: _Optional[_Iterable[str]] = ..., nodes: _Optional[_Iterable[_Union[Node, _Mapping]]] = ...) -> None: ...

class Node(_message.Message):
    __slots__ = ("version", "node_id", "create", "fetch", "exercise", "rollback", "lookup_by_key")
    class Fetch(_message.Message):
        __slots__ = ("contract_id", "package_name", "template_id", "signatories", "stakeholders", "acting_parties", "key_with_maintainers", "by_key")
        CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
        TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
        SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
        STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
        ACTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
        KEY_WITH_MAINTAINERS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        contract_id: str
        package_name: str
        template_id: _value_pb2.Identifier
        signatories: _containers.RepeatedScalarFieldContainer[str]
        stakeholders: _containers.RepeatedScalarFieldContainer[str]
        acting_parties: _containers.RepeatedScalarFieldContainer[str]
        key_with_maintainers: GlobalKeyWithMaintainers
        by_key: bool
        def __init__(self, contract_id: _Optional[str] = ..., package_name: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., signatories: _Optional[_Iterable[str]] = ..., stakeholders: _Optional[_Iterable[str]] = ..., acting_parties: _Optional[_Iterable[str]] = ..., key_with_maintainers: _Optional[_Union[GlobalKeyWithMaintainers, _Mapping]] = ..., by_key: bool = ...) -> None: ...
    class Exercise(_message.Message):
        __slots__ = ("fetch", "interface_id", "choice_id", "chosen_value", "consuming", "children", "exercise_result", "choice_observers", "choice_authorizers")
        FETCH_FIELD_NUMBER: _ClassVar[int]
        INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
        CHOICE_ID_FIELD_NUMBER: _ClassVar[int]
        CHOSEN_VALUE_FIELD_NUMBER: _ClassVar[int]
        CONSUMING_FIELD_NUMBER: _ClassVar[int]
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        EXERCISE_RESULT_FIELD_NUMBER: _ClassVar[int]
        CHOICE_OBSERVERS_FIELD_NUMBER: _ClassVar[int]
        CHOICE_AUTHORIZERS_FIELD_NUMBER: _ClassVar[int]
        fetch: Node.Fetch
        interface_id: _value_pb2.Identifier
        choice_id: str
        chosen_value: _value_pb2.Value
        consuming: bool
        children: _containers.RepeatedScalarFieldContainer[str]
        exercise_result: _value_pb2.Value
        choice_observers: _containers.RepeatedScalarFieldContainer[str]
        choice_authorizers: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, fetch: _Optional[_Union[Node.Fetch, _Mapping]] = ..., interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., choice_id: _Optional[str] = ..., chosen_value: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., consuming: bool = ..., children: _Optional[_Iterable[str]] = ..., exercise_result: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., choice_observers: _Optional[_Iterable[str]] = ..., choice_authorizers: _Optional[_Iterable[str]] = ...) -> None: ...
    class Rollback(_message.Message):
        __slots__ = ("children",)
        CHILDREN_FIELD_NUMBER: _ClassVar[int]
        children: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, children: _Optional[_Iterable[str]] = ...) -> None: ...
    class LookupByKey(_message.Message):
        __slots__ = ("package_name", "template_id", "key", "contract_id")
        PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
        TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        package_name: str
        template_id: _value_pb2.Identifier
        key: GlobalKeyWithMaintainers
        contract_id: str
        def __init__(self, package_name: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., key: _Optional[_Union[GlobalKeyWithMaintainers, _Mapping]] = ..., contract_id: _Optional[str] = ...) -> None: ...
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_FIELD_NUMBER: _ClassVar[int]
    FETCH_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_FIELD_NUMBER: _ClassVar[int]
    LOOKUP_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    version: str
    node_id: str
    create: Create
    fetch: Node.Fetch
    exercise: Node.Exercise
    rollback: Node.Rollback
    lookup_by_key: Node.LookupByKey
    def __init__(self, version: _Optional[str] = ..., node_id: _Optional[str] = ..., create: _Optional[_Union[Create, _Mapping]] = ..., fetch: _Optional[_Union[Node.Fetch, _Mapping]] = ..., exercise: _Optional[_Union[Node.Exercise, _Mapping]] = ..., rollback: _Optional[_Union[Node.Rollback, _Mapping]] = ..., lookup_by_key: _Optional[_Union[Node.LookupByKey, _Mapping]] = ...) -> None: ...

class Create(_message.Message):
    __slots__ = ("contract_id", "package_name", "template_id", "argument", "signatories", "stakeholders", "package_version", "global_key_with_maintainers")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
    STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_KEY_WITH_MAINTAINERS_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    package_name: str
    template_id: _value_pb2.Identifier
    argument: _value_pb2.Value
    signatories: _containers.RepeatedScalarFieldContainer[str]
    stakeholders: _containers.RepeatedScalarFieldContainer[str]
    package_version: str
    global_key_with_maintainers: GlobalKeyWithMaintainers
    def __init__(self, contract_id: _Optional[str] = ..., package_name: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., argument: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., signatories: _Optional[_Iterable[str]] = ..., stakeholders: _Optional[_Iterable[str]] = ..., package_version: _Optional[str] = ..., global_key_with_maintainers: _Optional[_Union[GlobalKeyWithMaintainers, _Mapping]] = ...) -> None: ...

class GlobalKey(_message.Message):
    __slots__ = ("template_id", "package_name", "key", "hash")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    package_name: str
    key: _value_pb2.Value
    hash: bytes
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., package_name: _Optional[str] = ..., key: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., hash: _Optional[bytes] = ...) -> None: ...

class GlobalKeyWithMaintainers(_message.Message):
    __slots__ = ("key", "maintainers")
    KEY_FIELD_NUMBER: _ClassVar[int]
    MAINTAINERS_FIELD_NUMBER: _ClassVar[int]
    key: GlobalKey
    maintainers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, key: _Optional[_Union[GlobalKey, _Mapping]] = ..., maintainers: _Optional[_Iterable[str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import event_pb2 as _event_pb2
from . import trace_context_pb2 as _trace_context_pb2
from . import value_pb2 as _value_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Reassignment(_message.Message):
    __slots__ = ("update_id", "command_id", "workflow_id", "offset", "unassigned_event", "assigned_event", "trace_context", "record_time")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNED_EVENT_FIELD_NUMBER: _ClassVar[int]
    ASSIGNED_EVENT_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    command_id: str
    workflow_id: str
    offset: int
    unassigned_event: UnassignedEvent
    assigned_event: AssignedEvent
    trace_context: _trace_context_pb2.TraceContext
    record_time: _timestamp_pb2.Timestamp
    def __init__(self, update_id: _Optional[str] = ..., command_id: _Optional[str] = ..., workflow_id: _Optional[str] = ..., offset: _Optional[int] = ..., unassigned_event: _Optional[_Union[UnassignedEvent, _Mapping]] = ..., assigned_event: _Optional[_Union[AssignedEvent, _Mapping]] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class UnassignedEvent(_message.Message):
    __slots__ = ("unassign_id", "contract_id", "template_id", "source", "target", "submitter", "reassignment_counter", "assignment_exclusivity", "witness_parties", "package_name")
    UNASSIGN_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_COUNTER_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_EXCLUSIVITY_FIELD_NUMBER: _ClassVar[int]
    WITNESS_PARTIES_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    unassign_id: str
    contract_id: str
    template_id: _value_pb2.Identifier
    source: str
    target: str
    submitter: str
    reassignment_counter: int
    assignment_exclusivity: _timestamp_pb2.Timestamp
    witness_parties: _containers.RepeatedScalarFieldContainer[str]
    package_name: str
    def __init__(self, unassign_id: _Optional[str] = ..., contract_id: _Optional[str] = ..., template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., source: _Optional[str] = ..., target: _Optional[str] = ..., submitter: _Optional[str] = ..., reassignment_counter: _Optional[int] = ..., assignment_exclusivity: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., witness_parties: _Optional[_Iterable[str]] = ..., package_name: _Optional[str] = ...) -> None: ...

class AssignedEvent(_message.Message):
    __slots__ = ("source", "target", "unassign_id", "submitter", "reassignment_counter", "created_event")
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    UNASSIGN_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_COUNTER_FIELD_NUMBER: _ClassVar[int]
    CREATED_EVENT_FIELD_NUMBER: _ClassVar[int]
    source: str
    target: str
    unassign_id: str
    submitter: str
    reassignment_counter: int
    created_event: _event_pb2.CreatedEvent
    def __init__(self, source: _Optional[str] = ..., target: _Optional[str] = ..., unassign_id: _Optional[str] = ..., submitter: _Optional[str] = ..., reassignment_counter: _Optional[int] = ..., created_event: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignedContent(_message.Message):
    __slots__ = ("content", "signatures", "timestamp_of_signing_key")
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_OF_SIGNING_KEY_FIELD_NUMBER: _ClassVar[int]
    content: _wrappers_pb2.BytesValue
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    timestamp_of_signing_key: _wrappers_pb2.Int64Value
    def __init__(self, content: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ..., timestamp_of_signing_key: _Optional[_Union[_wrappers_pb2.Int64Value, _Mapping]] = ...) -> None: ...
